==> cytoscape-3.25.0.jar: META-INF/resources/webjars/cytoscape/3.25.0/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Before you post**

A request for help or a requests for a how-to should be directed to Stack Overflow:
http://stackoverflow.com/questions/tagged/cytoscape.js

If your issue pertains to an extension, your issue should be filed in that extension's repository -- not here.



**Environment info**

- Cytoscape.js version :
- Browser/Node.js & version :



**Current (buggy) behaviour**

_What does the bug do?_



**Desired behaviour**

_What do you expect Cytoscape.js to do instead?_



**Minimum steps to reproduce**

_What do you need to do to reproduce the issue?_

_Fork/clone this JSBin demo and reproduce your issue so that your issue can be addressed quickly and effectively:_
http://jsbin.com/fiqugiq



**For reviewers**

_Reviewers should ensure that the following tasks are carried out for incorporated issues:_

- [ ] Ensure that the reporter has included a reproducible demo.  They can easily fork this JSBin demo: http://jsbin.com/fiqugiq
- [ ] The issue has been associated with a corresponding [milestone](https://github.com/cytoscape/cytoscape.js/milestones).
- [ ] The commits have been incorporated into the corresponding branches.  Bug-fix patches go on
    - [ ] `master`,
    - [ ] `unstable`, and
    - [ ] the previous feature release branch (e.g. `1.1.x` if the current release is 1.2).
- [ ] The issue has been labelled as a [`bug`](https://github.com/cytoscape/cytoscape.js/labels/bug), if necessary.

==> cytoscape-3.26.0.jar: META-INF/resources/webjars/cytoscape/3.26.0/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Let us know about a bug
title: ''
labels: bug
assignees: ''

---

**Before you post**

A request for help or a requests for a how-to should be directed to [Phind]([url](https://www.phind.com/search?c=I%27m%20using%20the%20Cytoscape.js%20graph%20theory%20JS%20library.&q=How%20do%20I%20create%20a%20graph%20in%20my%20HTML%20page)).

If your issue pertains to an extension, your issue should be filed in that extension's repository -- not here.



**Environment info**

- Cytoscape.js version :
- Browser/Node.js & version :



**Current (buggy) behaviour**

_What does the bug do?_



**Desired behaviour**

_What do you expect Cytoscape.js to do instead?_



**Minimum steps to reproduce**

_What do you need to do to reproduce the issue?_

_Fork/clone this JSBin demo and reproduce your issue so that your issue can be addressed quickly and effectively:_
http://jsbin.com/fiqugiq



**For reviewers**

_Reviewers should ensure that the following tasks are carried out for incorporated issues:_

- [ ] Ensure that the reporter has included a reproducible demo.  They can easily fork this JSBin demo: http://jsbin.com/fiqugiq
- [ ] The issue has been associated with a corresponding [milestone](https://github.com/cytoscape/cytoscape.js/milestones).
- [ ] The commits have been incorporated into the corresponding branches.  Bug-fix patches go on
    - [ ] `master`,
    - [ ] `unstable`, and
    - [ ] the previous feature release branch (e.g. `1.1.x` if the current release is 1.2).
- [ ] The issue has been labelled as a [`bug`](https://github.com/cytoscape/cytoscape.js/labels/bug), if necessary.
